#
# spec file for package nxtvepg
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           nxtvepg
Version:        2.8.1
Release:        bp153.1.17
Summary:        Nextview EPG Decoder and Browser
License:        GPL-2.0-or-later
Group:          Hardware/TV
Url:            http://nxtvepg.sourceforge.net/
Source0:        http://prdownloads.sourceforge.net/nxtvepg/%{name}-%{version}.tar.gz
Source1:        rc.nxtvepg
Patch1:         nxtvepg-Makefile.patch
Patch2:         nxtvepg-no-hardcoded-tcl-dir.patch
BuildRequires:  tcl-devel
BuildRequires:  tk-devel
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xmu)
Requires(pre):  %insserv_prereq

%description
In this software package, find a decoder for Nextview--an electronic TV
program guide for the analog domain (as opposed to the various digital
EPGs that come with most digital broadcasts). It allows you to decode
and browse TV program listings for most of the major networks in
Germany, Austria, France, and Switzerland.

Currently, Nextview EPG is transmitted by: * In Germany and Austria:
   Kabel1, 3Sat, RTL-II, EuroNews (coverage: apx. 31 networks)

* In Switzerland: SF1, TSR1, TSI1, EuroNews, 3sat, Kabel1 (coverage:
   apx. 37 networks)

* In France: Canal+, M6 (coverage: 8 networks)

* In Turkey: TRT-1 (coverage: 17 networks)

%prep
%setup -q
%patch1
%patch2

%build
export	CFLAGS="%{optflags}"
make	prefix=%{_prefix}			\
	mandir=%{_mandir}/man1	\
	SYS_DBDIR=%{_localstatedir}/tmp/nxtvdb

%install
make	ROOT=%{buildroot}		\
	prefix=%{_prefix}			\
	mandir=%{buildroot}%{_mandir}/man1	\
	SYS_DBDIR=%{_localstatedir}/tmp/nxtvdb	\
	install
# remove the daemon-only binary - /usr/bin/nxtvepg is capable of running as
# daemon too, so packaging nxtvepgd would mean duplication for most use cases
rm %{buildroot}%{_bindir}/nxtvepgd %{buildroot}%{_mandir}/man1/nxtvepgd.1*
# init script
mkdir -p %{buildroot}%{_initddir} %{buildroot}%{_prefix}/sbin
install -m 755 %{SOURCE1} %{buildroot}%{_initddir}/nxtvepg
ln -s ../..%{_initddir}/nxtvepg %{buildroot}%{_sbindir}/rcnxtvepg

%preun
%stop_on_removal nxtvepg

%postun
%restart_on_update nxtvepg
%insserv_cleanup

%files
%defattr(-,root,root)
%config %{_initddir}/nxtvepg
%{_sbindir}/rcnxtvepg
%{_bindir}/nxtvepg
%{_datadir}/nxtvepg
%{_mandir}/man1/nxtvepg.1*
%dir %{_datadir}/X11/app-defaults
%{_datadir}/X11/app-defaults/Nxtvepg
%doc CHANGES COPYRIGHT TODO README manual.html

%changelog
* Mon Mar 19 2018 crrodriguez@opensuse.org
- Change xorg-x11-devel --> pkgconfig(x11, xmu)
- Add explicit builrequires on tcl-devel
* Wed Mar 15 2017 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Use url for source
* Wed Mar 15 2017 dimstar@opensuse.org
- Add %%insserv_prereq PreReq: since we still install legacy initd
  services it is our own duty to ensure the legacy tools to handle
  them are installed.
* Sat Mar 17 2012 toganm@opensuse.org
- add %%dir /usr/share/X11/app-defaults to fix factory build
* Tue Aug 11 2009 mmarek@suse.cz
- updated to 2.8.1, for changes see
  http://nxtvepg.sourceforge.net/changelog.html#release_2_8_1
* Tue Apr  8 2008 mmarek@suse.cz
- don't hardcode {TCL,TK}_LIBRARY_PATH, tcl knows it's installation
  paths already
- added patch to fix a crash with new Tcl/Tk
* Mon Feb  4 2008 mmarek@suse.cz
- updated to version 2.8.0
  * import and merge of EPG data from XMLTV files
  * Implemented new communication protocol for TV applications
    which allows to more EPG data (Download the tvsim package to
    get a demo) Not yet used by any TV applications.
  * added possibility to use an external program to display EPG
    info popups to TV app. interaction configuration
  * added new command line option -provscan de|fr|at|ch: runs an
    EPG scan without GUI. It can also be used by nxtvepgd, so
    nxtvepg can now be set up without ever using the GUI (except
    for some advanced acquisition options)
  * added command line option -remctrl for UNIX (was supported on
    WIN32 only)
  * Added support for export in HTML format via the command line:
  - dump html (does not support all features available in the GUI
    though.)
* Tue Aug  7 2007 mmarek@suse.cz
- updated to version 2.7.7
  * Implemented new algorithm in EPG stream decoder to improve
    performance under bad reception conditions (i.e. with high data
    loss rates)
  * bugfix in TV app detection -> fixes interaction with
    "tvtime"
  * Minor bugfix in display of user-defined separators in programme
    list's context menu
  * Minor bugfix in reminder message popup windows: font for
    programme title can now be changed with "pi_font" in the
    resource file (i.e.  file Nxtvepg.ad or via X11 resources on
    UNIX)
  * Work-around for bttv driver bug in kernel 2.6.16 (fixed
    in 2.6.18)  Thanks to all the people in the nxtvepg forum who
    helped debugging this and esp. to Lars for providing the first
    work-around.
  * improved portability of timezone offset calculation
  * Excluded deceased providers "RTL2" (Germany) and "VT" (Belgium)
    from documentation and the EPG scan's list of pre-defined
    providers.
  * Many fixes and improvements in the German documentation; Thanks
    again to Kurt Lettmaier
  * Added German translation of the manual and help pages.
    Many thanks to Olaf Noehring and Kurt Lettmaier for
    contributing the translation.
  * Major bugfix in reminder removal (when removing multiple
    reminders in the same order they were created, the wrong
    reminder was removed and nxtvepg could even crash.) Thanks to
    Kurt for reporting this bug.
  * Added menu entry "Edit filter-based reminders" to promote the
    possibility to create reminders based on shortcuts.
  * Minor fix in XMLTV export (DTD 0.6): several elements were not
    in the correct order, which caused warnings with some XML
    processors
  * Provider scan now issues an appropriate error message
    upon device errors (Thanks to Andreas for reporting this
    problem)
- added insserv macros to %%preun and %%postun
* Thu Aug 17 2006 cthiel@suse.de
- fix build with X.Org 7.1
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jul 27 2005 kraxel@suse.de
- update to version 2.7.5.
* Mon Jul 25 2005 mmj@suse.de
- adapt new tcl location
* Fri Jan  7 2005 kraxel@suse.de
- update to version 2.7.4.
* Tue Aug 17 2004 kraxel@suse.de
- update to version 2.7.1.
* Thu Apr 22 2004 kraxel@suse.de
- update to version 2.7.0.
* Sun Jan  4 2004 kraxel@suse.de
- update to version 2.6.0.
* Mon Jul 28 2003 ro@suse.de
- added tk-devel to neededforbuild
* Wed Mar 26 2003 kraxel@suse.de
- updated to version 2.5.0.
* Tue Jan 14 2003 kraxel@suse.de
- updated to version 2.4.2.
- added init script for daemon mode.
* Tue Dec 10 2002 kraxel@suse.de
- updated to version 2.4.1
* Mon Nov 11 2002 ro@suse.de
- changed neededforbuild <xf86 xdevel xshared> to <x-devel-packages>
* Tue Oct 15 2002 kraxel@suse.de
- updated to version 2.3.1
* Mon Jul 22 2002 kraxel@suse.de
- updated to version 0.7.4
* Tue Jul 16 2002 max@suse.de
- Apply the Tcl/Tk 8.4 patch only if that version is actually
  present, to be safe in case we have to switch back to 8.3.
* Mon Jul 15 2002 kraxel@suse.de
- fixed build problems due to tcl/tk 8.4 update.
* Thu Apr 11 2002 kraxel@suse.de
- updated to version 0.7.0
* Tue Feb 26 2002 kraxel@suse.de
- fixed s390x build problems.
* Wed Dec  5 2001 kraxel@suse.de
- updated to version 0.6.4 (bugfixes, daemon mode for data collection
  without GUI, lots of small GUI improvements)
* Fri Jul 20 2001 kraxel@suse.de
- first release.
